package VerifyTemplate

import (
	"bzd_server/lib"
	"bzd_server/logs"
	"fmt"
	"github.com/beego/beego/v2/adapter/orm"
	orm2 "github.com/beego/beego/v2/client/orm"
	_ "github.com/go-sql-driver/mysql"
	"time"
)
// 模板
type VerifyTemplate struct {
	Id int `orm:"column(ID);size(11);auto;pk"`

	T_VerifyTemplate_id  string `orm:"size(256);null"`  // 标题
	T_name  string `orm:"size(256);null"`  // 标题
	T_sort    int       `orm:"size(2);1"`                                             // 排序

	CreateTime time.Time `orm:"column(create_time);type(timestamp);null;auto_now_add"` //auto_now_add 第一次保存时才设置时间
	UpdateTime time.Time `orm:"column(update_time);type(timestamp);null;auto_now"`     //auto_now 每次 model 保存时都会对时间自动更新
}

type VerifyTemplate_R struct {
	T_VerifyTemplate_id  string `orm:"size(256);null"`  // 标题
	T_name  string `orm:"size(256);null"`  // 标题
	T_sort int    `orm:"size(200);null"`  // 分类

}

func (t *VerifyTemplate) TableName() string {
	return "VerifyTemplate" // 数据库名称   // ************** 替换 FormulaList **************
}

func init() {

	//注册模型
	orm.RegisterModel(new(VerifyTemplate))

}
// -------------------------------------------------------------
func VerifyTemplateToVerifyTemplate_R(T VerifyTemplate) (T_r VerifyTemplate_R) {
	T_r.T_VerifyTemplate_id = T.T_VerifyTemplate_id
	T_r.T_name = T.T_name
	T_r.T_sort = T.T_sort

	//......
	return T_r
}

// ---------------- 特殊方法 -------------------

// 获取 ById
func Read_VerifyTemplate_ById(id int) (r VerifyTemplate, is bool) {
	o := orm.NewOrm()
	r = VerifyTemplate{Id: id}
	err := o.Read(&r) // o.Read(&r,"Tokey") 如果不是 主键 就得指定字段名
	if err != nil {
		logs.Println(err)
		return r, false
	}
	return r, true
}

// 获取 By
func Read_VerifyTemplate(T_VerifyTemplate_id string) (r VerifyTemplate, is bool) {

	o := orm.NewOrm()
	qs := o.QueryTable(new(VerifyTemplate))
	err := qs.Filter("T_VerifyTemplate_id", T_VerifyTemplate_id).One(&r)
	if err != nil {
		return r, false
	}

	return r, true
}

// 添加
func Add_VerifyTemplate(r VerifyTemplate) (id int64, is bool) {
	o := orm.NewOrm()

	// 生成编号
	rand_x := 0
	for true {
		r.T_VerifyTemplate_id = lib.GetRandstring(4, "", int64(rand_x)) // 1,336,336
		err := o.Read(&r, "T_VerifyTemplate_id") // o.Read(&r,"Tokey") 如果不是 主键 就得指定字段名
		if err != nil {
			break
		}
		rand_x += 1
	}

	id, err := o.Insert(&r)
	if err != nil {
		logs.Println(err)
		return 0, false
	}

	return id, true
}

// 删除
func Delete_VerifyTemplate(v VerifyTemplate) bool {
	o := orm.NewOrm()
	if num, err := o.Delete(&v); err == nil {
		logs.Println("Number of records deleted in database:", num)
	} else {
		return false
	}

	return true
}


// 修改
func Update_VerifyTemplate(m VerifyTemplate,cols ...string) bool {
	o := orm.NewOrm()
	if num, err := o.Update(&m, cols...); err == nil {
		fmt.Println("Number of records updated in database:", num)
		return true
	}
	return false
}

// 获取列表
func Read_VerifyTemplate_List(T_name string) ( []VerifyTemplate_R) {

	o := orm.NewOrm()
	// 也可以直接使用 Model 结构体作为表名
	var r []VerifyTemplate
	qs := o.QueryTable(new(VerifyTemplate))

	cond := orm.NewCondition()
	cond1 := cond.And("T_name__icontains", T_name) // .AndNot("status__in", 1).Or("profile__age__gt", 2000)


	qs.SetCond((*orm2.Condition)(cond1)).OrderBy("-Id").All(&r)

	// 转换
	var VerifyTemplate_r []VerifyTemplate_R
	for _,v := range r{
		VerifyTemplate_r = append(VerifyTemplate_r, VerifyTemplateToVerifyTemplate_R(v))
	}

	return VerifyTemplate_r
}
